@@ -19,7 +19,7 @@ import pdfplumber
 from magic import MagicException
 from ocrmypdf import ocr
 from sortedcontainers import SortedSet
-from tqdm.contrib.concurrent import thread_map
+from tqdm.contrib.concurrent import process_map
 
 from plagdef.model import models
 
@@ -43,8 +43,8 @@ class DocumentFileRepository:
 
     def list(self) -> set[models.Document]:
         files = list(self._list_files())
-        docs = thread_map(self._read_file, files, desc=f"Reading documents in '{self.dir_path}'",
-                          unit='doc', total=len(files), max_workers=os.cpu_count())
+        docs = process_map(self._read_file, files, desc=f"Reading documents in '{self.dir_path}'",
+                           unit='doc', total=len(files), max_workers=os.cpu_count())
         return set(filter(None, docs))
 
     def _read_file(self, file):
@@ -153,7 +153,8 @@ class PdfReader:
         if self._poor_extraction(text):
             log.warning(f"Poor text extraction in '{self._file.name}' detected! Using OCR...")
             with BytesIO() as ocr_file:
-                ocr(self._file, ocr_file, language=self._lang, force_ocr=True, progress_bar=False)
+                ocr(self._file, ocr_file, language=self._lang, force_ocr=True, progress_bar=False,
+                    max_image_mpixels=512)
                 text = self._extract(ocr_file)
         return text
 
